import React, { useEffect, useState } from "react";
import {
  Button,
  Form,
  Input,
  message,
  Modal,
  Select,
  Space,
  Table,
  Tag,
} from "antd";
import { observer } from "mobx-react-lite";
import { ExclamationCircleOutlined } from "@ant-design/icons";
import { useHistory } from "react-router-dom";
import { capitalize } from "lodash";
import { useStore } from "../utils/useStore";
import { LINKS } from "../routes/app";

export const SupplierComponent = observer((props) => {
  const store = useStore();
  const [form] = Form.useForm();
  const { Option } = Select;
  const history = useHistory();
  const [idData, setIdData] = useState("");
  const [confirmLoading, setConfirmLoading] = useState(false);
  const [isLoading, setIsLoading] = useState(false);

  useEffect(() => {
    const init = async () => {
      try {
        setIsLoading(true);
        await store.supplier.getData();
        setIsLoading(false);
      } catch (e) {
        setIsLoading(false);
      }
    };

    init();
  }, []);

  const handleEditButton = (data) => {
    console.log(data, "isi data");
    form.setFieldsValue({
      name: data.name,
      code: data.code,
      status:data.status
    });
    store.supplier.visibleModalSupplier = true;
    setIdData(data.id);
  };

  const columns = [
    {
      title: "Name",
      dataIndex: "name",
      key: "name",
    },
    {
      title: "Kode",
      dataIndex: "code",
      key: "code",
    },
    {
      title: "Status",
      dataIndex: "status",
      key: "status",
      render: (text, record) => (
        <Tag
          color={record?.status === true ? "blue" : "#E3E8EE"}
          style={{ color: "#4F566B" }}
        >
          {record?.status === true ? " ACTIVE" : "INACTIVE"}
        </Tag>
      ),
    },
    {
      title: "Action",
      key: "action",
      render: (text, record) => (
        <Space size="middle">
          <Button onClick={() => handleEditButton(record)}>Edit</Button>
          <Button onClick={() => handleDelete(record.id)}>Delete</Button>
        </Space>
      ),
    },
  ];

  const deleteData = async (id) => {
    try {
      console.log(id);
      await store.supplier.delete(id);
      message.success("Data Berhasil Dihapus");
      history.push(LINKS.PRODUCT);
    } catch (err) {
      console.log("error", err);
      message.error("Gagal menghapus");
    }
  };

  const handleDelete = (id) => {
    Modal.confirm({
      title: "Are you sure delete this record?",
      icon: <ExclamationCircleOutlined />,
      okText: "Yes",
      okType: "primary",
      cancelText: "Cancel",
      onOk() {
        return deleteData(id);
      },
      onCancel() {
        console.log("Cancel");
      },
    });
  };

  const handleCancel = () => {
    setIdData("");
    store.supplier.visibleModalSupplier = false;
  };
  const handleCancelTransaction= () => {
    store.supplier.visibleModalTransaction = false;
  };

  const handleSubmit = async (data) => {
    console.log(data, "isi data2");
    if (idData !== "") {
      setConfirmLoading(true);
      try {
        await store.supplier.update(idData, data);
        message.success("Success Update Data Member");
      } catch (e) {
        message.error("Failed Update Data Member");
      }
      setConfirmLoading(false);
      store.supplier.visibleModalSupplier = false;
      setIdData("");
      form.resetFields();
    } else {
      setConfirmLoading(true);
      try {
        await store.supplier.create(data);
        message.success("Success Add New Member");
        //await store.supplier.getData()
      } catch (e) {
        console.log(e, "apa errornya");
        message.error("Failed Add Member");
      }
      setConfirmLoading(false);
      store.supplier.visibleModalSupplier = false;
      setIdData("");
      form.resetFields();
    }
  };

  const handleSubmitTransaction = async (data) => {
    console.log(data, "isi data2");
      setConfirmLoading(true);
      try {
        await store.supplier.createTransaction(data);
        message.success("Success Top Up");
        //await store.supplier.getData()
      } catch (e) {
        console.log(e, "apa errornya");
        message.error("Failed Top Up");
      }
      setConfirmLoading(false);
      store.supplier.visibleModalTransaction = false;
      form.resetFields();
  };  

  

  return (
    <div>
      <Table
        style={{ textAlign: "center" }}
        columns={columns}
        dataSource={store.supplier.data}
        bordered
        pagination={{
          pageSize: store.supplier.pageSize,
          total: store.supplier.total_data,
          current: store.supplier.page + 1,
          showSizeChanger: true,
          simple: false,
        }}
        onChange={async (page) => {
          let pageNumber = page.current;
          store.supplier.pageSize = page.pageSize;
          store.supplier.page = pageNumber - 1;
          // store.membership.isLoading = true;
          await store.supplier.getData();
          // store.membership.isLoading = false;
        }}
      />

      <Modal
        visible={store.supplier.visibleModalSupplier}
        title={idData ? "Edit Supplier" : "Create a new Supplier"}
        okText={idData ? "Edit" : "Create"}
        cancelText="Cancel"
        onCancel={() => {
          form.resetFields();
          handleCancel();
        }}
        onOk={() => {
          form
            .validateFields()
            .then((values) => {
              console.log(values, "isi form");
              handleSubmit(values);
              form.resetFields();
            })
            .catch((info) => {
              console.error("Validate Failed:", info);
            });
        }}
      >
        <Form form={form} layout="vertical">
          <Form.Item
            name="name"
            label="Name"
            rules={[{ required: true, message: "Please input name!" }]}
          >
            <Input />
          </Form.Item>
          <Form.Item
            name="code"
            label="Kode"
            rules={[{ required: true, message: "Please input kode!" }]}
          >
            <Input />
          </Form.Item>
        </Form>
      </Modal>
      <Modal
        visible={store.supplier.visibleModalTransaction}
        title="Top Up Saldo"
        okText="Top Up"
        cancelText="Cancel"
        onCancel={() => {
          form.resetFields();
          handleCancelTransaction();
        }}
        onOk={() => {
          form
            .validateFields()
            .then((values) => {
              console.log(values, "isi form");
              handleSubmitTransaction(values);
              form.resetFields();
            })
            .catch((info) => {
              console.error("Validate Failed:", info);
            });
        }}
      >
        <Form form={form} layout="vertical">
          <Form.Item
            name="supplier"
            label="Supplier"
            rules={[{ required: true, message: "Please input supplier!" }]}
          >
            <Input />
          </Form.Item>
          <Form.Item
            name="amount"
            label="Amount"
            rules={[{ required: true, message: "Please input amount!" }]}
          >
            <Input />
          </Form.Item>
        </Form>
      </Modal>
    </div>
  );
});
