import React, { useEffect, useState } from "react";
import { Button, Card, Col, Input, Row, Tabs } from "antd";
import { FilterOutlined, PlusSquareOutlined } from "@ant-design/icons";
import { BreadcumbComponent } from "../../component/BreadcumbComponent";
import { useStore } from "../../utils/useStore";
import { observer } from "mobx-react-lite";
import { LINKS } from "../../routes/app";
import { CategoryComponent } from "../../component/CategoryComponent";

const { TabPane } = Tabs;
const { Search } = Input;

export const Category = observer(() => {
  const [isLoading, setIsLoading] = useState(false);
  const store = useStore();

  useEffect(() => {
    const init = async () => {
      try {
        setIsLoading(true);
        //await store.product.getDataCategories();
        await store.category.getData();
        setIsLoading(false);
      } catch (e) {
        setIsLoading(false);
      }
    };

    init();
  }, []);

  const handleChangeTabPane = async (key) => {
    store.product.filterCategory = key;
    console.log(key);
  };

  const routeData = [
    {
      route: LINKS.HOME,
      name: "Home",
    },
    {
      route: LINKS.CATEGORY,
      name: <span style={{ fontWeight: "bold" }}>Category</span>,
    },
  ];

  return (
    <div className={["ppob-container"].join(" ")}>
      <BreadcumbComponent data={routeData} />
      <Card>
        <Row style={{ marginBottom: 20 }}>
          <Col span={12}>
            <Button>
              <FilterOutlined />
              Filter
            </Button>
          </Col>
          <Col span={12} style={{ textAlign: "right" }}>
            <Search
              placeholder="input search text"
              style={{
                width: store.ui.mediaQuery.isMobile ? 160 : 200,
                marginRight: store.ui.mediaQuery.isMobile ? 0 : 10,
                marginBottom: store.ui.mediaQuery.isMobile ? 10 : 0,
              }}
            />
            <Button onClick={() => (store.category.visibleModalCategory = true)}>
              <PlusSquareOutlined /> New
            </Button>
          </Col>
        </Row>

        <Tabs onChange={handleChangeTabPane} size="default" tabBarGutter="50">
            <TabPane tab="Category" key="1">
              <CategoryComponent/>
            </TabPane>
          ))}
        </Tabs>
      </Card>
    </div>
  );
});
